@@ -1,18 +1,18 @@
-# -*- coding: utf-8 -*-
 """
 Management of SQLite3 databases
 ===============================
 
+.. versionadded:: 2016.3.0
+
 :depends:   - SQLite3 Python Module
 :configuration: See :py:mod:`salt.modules.sqlite3` for setup instructions
-.. versionadded:: 2016.3.0
 
 The sqlite3 module is used to create and manage sqlite3 databases
 and execute queries
 
 Here is an example of creating a table using sql statements:
 
-  .. code-block:: yaml
+.. code-block:: yaml
 
     users:
       sqlite3.table_present:
@@ -22,7 +22,7 @@ Here is an example of creating a table using sql statements:
 
 Here is an example of creating a table using yaml/jinja instead of sql:
 
-  .. code-block:: yaml
+.. code-block:: yaml
 
     users:
       sqlite3.table_present:
@@ -38,7 +38,7 @@ Here is an example of creating a table using yaml/jinja instead of sql:
 
 Here is an example of making sure a table is absent:
 
-  .. code-block:: yaml
+.. code-block:: yaml
 
     badservers:
       sqlite3.table_absent:
@@ -48,7 +48,7 @@ Here is an example of making sure a table is absent:
 Sometimes you would to have specific data in tables to be used by other services
 Here is an example of making sure rows with specific data exist:
 
-  .. code-block:: yaml
+.. code-block:: yaml
 
     user_john_doe_xyz:
       sqlite3.row_present:
@@ -68,7 +68,7 @@ Here is an example of making sure rows with specific data exist:
 
 Here is an example of removing a row from a table:
 
-  .. code-block:: yaml
+.. code-block:: yaml
 
     user_john_doe_abc:
       sqlite3.row_absent:
@@ -81,7 +81,7 @@ Here is an example of removing a row from a table:
 Note that there is no explicit state to perform random queries, however, this
 can be approximated with sqlite3's module functions and module.run:
 
-  .. code-block:: yaml
+.. code-block:: yaml
 
     zone-delete:
       module.run:
@@ -92,11 +92,6 @@ can be approximated with sqlite3's module functions and module.run:
           - sqlite3: zone-insert-12
 """
 
-# Import Python libs
-from __future__ import absolute_import
-
-# Import Salt libs
-import salt.ext.six as six
 
 try:
     import sqlite3
@@ -110,7 +105,9 @@ def __virtual__():
     """
     Only load if the sqlite3 module is available
     """
-    return HAS_SQLITE3
+    if HAS_SQLITE3:
+        return True
+    return (False, "Unable to import sqlite3")
 
 
 def row_absent(name, db, table, where_sql, where_args=None):
@@ -133,51 +130,52 @@ def row_absent(name, db, table, where_sql, where_args=None):
     where_args
         The list parameters to substitute in where_sql
     """
-    changes = {'name': name,
-               'changes': {},
-               'result': None,
-               'comment': ''}
+    changes = {"name": name, "changes": {}, "result": None, "comment": ""}
     conn = None
     try:
         conn = sqlite3.connect(db, detect_types=sqlite3.PARSE_DECLTYPES)
         conn.row_factory = _dict_factory
         rows = None
         if where_args is None:
-            rows = _query(conn,
-                          "SELECT * FROM `" + table + "` WHERE " + where_sql)
+            rows = _query(conn, "SELECT * FROM `" + table + "` WHERE " + where_sql)
         else:
-            rows = _query(conn,
-                          "SELECT * FROM `" + table + "` WHERE " + where_sql,
-                          where_args)
+            rows = _query(
+                conn, "SELECT * FROM `" + table + "` WHERE " + where_sql, where_args
+            )
 
         if len(rows) > 1:
-            changes['result'] = False
-            changes['comment'] = "More than one row matched the specified query"
+            changes["result"] = False
+            changes["comment"] = "More than one row matched the specified query"
         elif len(rows) == 1:
-            if __opts__['test']:
-                changes['result'] = True
-                changes['comment'] = "Row will be removed in " + table
-                changes['changes']['old'] = rows[0]
+            if __opts__["test"]:
+                changes["result"] = True
+                changes["comment"] = "Row will be removed in " + table
+                changes["changes"]["old"] = rows[0]
 
             else:
-                cursor = conn.execute("DELETE FROM `" +
-                                      table + "` WHERE " + where_sql,
-                                      where_args)
+                if where_args is None:
+                    cursor = conn.execute(
+                        "DELETE FROM `" + table + "` WHERE " + where_sql
+                    )
+                else:
+                    cursor = conn.execute(
+                        "DELETE FROM `" + table + "` WHERE " + where_sql, where_args
+                    )
                 conn.commit()
                 if cursor.rowcount == 1:
-                    changes['result'] = True
-                    changes['comment'] = "Row removed"
-                    changes['changes']['old'] = rows[0]
+                    changes["result"] = True
+                    changes["comment"] = "Row removed"
+                    changes["changes"]["old"] = rows[0]
                 else:
-                    changes['result'] = False
-                    changes['comment'] = "Unable to remove row"
+                    changes["result"] = False
+                    changes["comment"] = "Unable to remove row"
         else:
-            changes['result'] = True
-            changes['comment'] = 'Row is absent'
+            changes["result"] = True
+            changes["comment"] = "Row is absent"
 
-    except Exception as e:
-        changes['result'] = False
-        changes['comment'] = str(e)
+    except Exception as e:  # pylint: disable=broad-except
+        changes["result"] = False
+        changes["comment"] = str(e)
 
     finally:
         if conn:
@@ -186,13 +184,7 @@ def row_absent(name, db, table, where_sql, where_args=None):
     return changes
 
 
-def row_present(name,
-                db,
-                table,
-                data,
-                where_sql,
-                where_args=None,
-                update=False):
+def row_present(name, db, table, data, where_sql, where_args=None, update=False):
     """
     Checks to make sure the given row exists. If row exists and update is True
     then row will be updated with data. Otherwise it will leave existing
@@ -225,38 +217,34 @@ def row_present(name,
         When False and the row exists and data does not equal
         the row data then the state will fail
     """
-    changes = {'name': name,
-               'changes': {},
-               'result': None,
-               'comment': ''}
+    changes = {"name": name, "changes": {}, "result": None, "comment": ""}
     conn = None
     try:
         conn = sqlite3.connect(db, detect_types=sqlite3.PARSE_DECLTYPES)
         conn.row_factory = _dict_factory
         rows = None
         if where_args is None:
-            rows = _query(conn, "SELECT * FROM `" +
-                                table + "` WHERE " + where_sql)
+            rows = _query(conn, "SELECT * FROM `" + table + "` WHERE " + where_sql)
         else:
-            rows = _query(conn, "SELECT * FROM `" +
-                                table + "` WHERE " + where_sql,
-                                where_args)
+            rows = _query(
+                conn, "SELECT * FROM `" + table + "` WHERE " + where_sql, where_args
+            )
 
         if len(rows) > 1:
-            changes['result'] = False
-            changes['comment'] = 'More than one row matched the specified query'
+            changes["result"] = False
+            changes["comment"] = "More than one row matched the specified query"
         elif len(rows) == 1:
-            for key, value in six.iteritems(data):
+            for key, value in data.items():
                 if key in rows[0] and rows[0][key] != value:
                     if update:
-                        if __opts__['test']:
-                            changes['result'] = True
-                            changes['comment'] = "Row will be update in " + table
+                        if __opts__["test"]:
+                            changes["result"] = True
+                            changes["comment"] = "Row will be update in " + table
 
                         else:
                             columns = []
                             params = []
-                            for key, value in six.iteritems(data):
+                            for key, value in data.items():
                                 columns.append("`" + key + "`=?")
                                 params.append(value)
 
@@ -270,33 +258,34 @@ def row_present(name,
                             cursor = conn.execute(sql, params)
                             conn.commit()
                             if cursor.rowcount == 1:
-                                changes['result'] = True
-                                changes['comment'] = "Row updated"
-                                changes['changes']['old'] = rows[0]
-                                changes['changes']['new'] = data
+                                changes["result"] = True
+                                changes["comment"] = "Row updated"
+                                changes["changes"]["old"] = rows[0]
+                                changes["changes"]["new"] = data
                             else:
-                                changes['result'] = False
-                                changes['comment'] = "Row update failed"
+                                changes["result"] = False
+                                changes["comment"] = "Row update failed"
                     else:
-                        changes['result'] = False
-                        changes['comment'] = "Existing data does" + \
-                                             "not match desired state"
+                        changes["result"] = False
+                        changes["comment"] = (
+                            "Existing data does" + "not match desired state"
+                        )
                         break
 
-            if changes['result'] is None:
-                changes['result'] = True
-                changes['comment'] = "Row exists"
+            if changes["result"] is None:
+                changes["result"] = True
+                changes["comment"] = "Row exists"
         else:
-            if __opts__['test']:
-                changes['result'] = True
-                changes['changes']['new'] = data
-                changes['comment'] = "Row will be inserted into " + table
+            if __opts__["test"]:
+                changes["result"] = True
+                changes["changes"]["new"] = data
+                changes["comment"] = "Row will be inserted into " + table
             else:
                 columns = []
                 value_stmt = []
                 values = []
-                for key, value in six.iteritems(data):
-                    value_stmt.append('?')
+                for key, value in data.items():
+                    value_stmt.append("?")
                     values.append(value)
                     columns.append("`" + key + "`")
 
@@ -308,16 +297,16 @@ def row_present(name,
                 cursor = conn.execute(sql, values)
                 conn.commit()
                 if cursor.rowcount == 1:
-                    changes['result'] = True
-                    changes['changes']['new'] = data
-                    changes['comment'] = 'Inserted row'
+                    changes["result"] = True
+                    changes["changes"]["new"] = data
+                    changes["comment"] = "Inserted row"
                 else:
-                    changes['result'] = False
-                    changes['comment'] = "Unable to insert data"
+                    changes["result"] = False
+                    changes["comment"] = "Unable to insert data"
 
-    except Exception as e:
-        changes['result'] = False
-        changes['comment'] = str(e)
+    except Exception as e:  # pylint: disable=broad-except
+        changes["result"] = False
+        changes["comment"] = str(e)
 
     finally:
         if conn:
@@ -336,37 +325,36 @@ def table_absent(name, db):
     db
         The name of the database file
     """
-    changes = {'name': name,
-               'changes': {},
-               'result': None,
-               'comment': ''}
+    changes = {"name": name, "changes": {}, "result": None, "comment": ""}
     conn = None
     try:
         conn = sqlite3.connect(db, detect_types=sqlite3.PARSE_DECLTYPES)
-        tables = _query(conn, "SELECT sql FROM sqlite_master " +
-                              " WHERE type='table' AND name=?", [name])
+        tables = _query(
+            conn,
+            "SELECT sql FROM sqlite_master " + " WHERE type='table' AND name=?",
+            [name],
+        )
 
         if len(tables) == 1:
-            if __opts__['test']:
-                changes['result'] = True
-                changes['comment'] = "'" + name + "' will be dropped"
+            if __opts__["test"]:
+                changes["result"] = True
+                changes["comment"] = "'" + name + "' will be dropped"
             else:
                 conn.execute("DROP TABLE " + name)
                 conn.commit()
-                changes['changes']['old'] = tables[0][0]
-                changes['result'] = True
-                changes['comment'] = "'" + name + "' was dropped"
+                changes["changes"]["old"] = tables[0][0]
+                changes["result"] = True
+                changes["comment"] = "'" + name + "' was dropped"
         elif len(tables) == 0:
-            changes['result'] = True
-            changes['comment'] = "'" + name + "' is already absent"
+            changes["result"] = True
+            changes["comment"] = "'" + name + "' is already absent"
         else:
-            changes['result'] = False
-            changes['comment'] = "Multiple tables with the same name='" + \
-                                 name + "'"
+            changes["result"] = False
+            changes["comment"] = "Multiple tables with the same name='" + name + "'"
 
-    except Exception as e:
-        changes['result'] = False
-        changes['comment'] = str(e)
+    except Exception as e:  # pylint: disable=broad-except
+        changes["result"] = False
+        changes["comment"] = str(e)
 
     finally:
         if conn:
@@ -393,16 +381,15 @@ def table_present(name, db, schema, force=False):
         the state will fail.  If force is set to True, the existing
         table will be replaced with the new table
     """
-    changes = {'name': name,
-               'changes': {},
-               'result': None,
-               'comment': ''}
+    changes = {"name": name, "changes": {}, "result": None, "comment": ""}
     conn = None
     try:
         conn = sqlite3.connect(db, detect_types=sqlite3.PARSE_DECLTYPES)
-        tables = _query(conn,
-                        "SELECT sql FROM sqlite_master " +
-                        "WHERE type='table' AND name=?", [name])
+        tables = _query(
+            conn,
+            "SELECT sql FROM sqlite_master " + "WHERE type='table' AND name=?",
+            [name],
+        )
 
         if len(tables) == 1:
             sql = None
@@ -413,27 +400,27 @@ def table_present(name, db, schema, force=False):
 
             if sql != tables[0][0]:
                 if force:
-                    if __opts__['test']:
-                        changes['result'] = True
-                        changes['changes']['old'] = tables[0][0]
-                        changes['changes']['new'] = sql
-                        changes['comment'] = "'" + name + "' will be replaced"
+                    if __opts__["test"]:
+                        changes["result"] = True
+                        changes["changes"]["old"] = tables[0][0]
+                        changes["changes"]["new"] = sql
+                        changes["comment"] = "'" + name + "' will be replaced"
                     else:
                         conn.execute("DROP TABLE `" + name + "`")
                         conn.execute(sql)
                         conn.commit()
-                        changes['result'] = True
-                        changes['changes']['old'] = tables[0][0]
-                        changes['changes']['new'] = sql
-                        changes['comment'] = "Replaced '" + name + "'"
+                        changes["result"] = True
+                        changes["changes"]["old"] = tables[0][0]
+                        changes["changes"]["new"] = sql
+                        changes["comment"] = "Replaced '" + name + "'"
                 else:
-                    changes['result'] = False
-                    changes['comment'] = "Expected schema=" + sql + \
-                                         "\nactual schema=" + tables[0][0]
+                    changes["result"] = False
+                    changes["comment"] = (
+                        "Expected schema=" + sql + "\nactual schema=" + tables[0][0]
+                    )
             else:
-                changes['result'] = True
-                changes['comment'] = "'" + name + \
-                                     "' exists with matching schema"
+                changes["result"] = True
+                changes["comment"] = "'" + name + "' exists with matching schema"
         elif len(tables) == 0:
             # Create the table
             sql = None
@@ -441,23 +428,23 @@ def table_present(name, db, schema, force=False):
                 sql = schema
             else:
                 sql = _get_sql_from_schema(name, schema)
-            if __opts__['test']:
-                changes['result'] = True
-                changes['changes']['new'] = sql
-                changes['comment'] = "'" + name + "' will be created"
+            if __opts__["test"]:
+                changes["result"] = True
+                changes["changes"]["new"] = sql
+                changes["comment"] = "'" + name + "' will be created"
             else:
                 conn.execute(sql)
                 conn.commit()
-                changes['result'] = True
-                changes['changes']['new'] = sql
-                changes['comment'] = "Created table '" + name + "'"
+                changes["result"] = True
+                changes["changes"]["new"] = sql
+                changes["comment"] = "Created table '" + name + "'"
         else:
-            changes['result'] = False
-            changes['comment'] = 'Multiple tables with the same name=' + name
+            changes["result"] = False
+            changes["comment"] = "Multiple tables with the same name=" + name
 
-    except Exception as e:
-        changes['result'] = False
-        changes['comment'] = str(e)
+    except Exception as e:  # pylint: disable=broad-except
+        changes["result"] = False
+        changes["comment"] = str(e)
 
     finally:
         if conn:
